import 'package:code_id_storage/code_interfaces/storage/i_collection_storage.dart';
import 'package:code_id_storage/code_services/storage/hive_keys.dart';
import 'package:hive_flutter/hive_flutter.dart';

class CollectionStorage implements ICollectionStorage {
  late BoxCollection _collection;
  // CollectionBox<V>? _box;
  CollectionStorage({
    required String databaseName,
    required Set<String> boxNames,
  }) {
    openCollection(
      databaseName: databaseName,
      boxNames: boxNames,
    );
  }

  Future<BoxCollection> openCollection({
    required String databaseName,
    required Set<String> boxNames,
  }) async {
    final List<int> keys = await hiveKeys();
    _collection = await BoxCollection.open(
      databaseName,
      boxNames,
      path: './',
      key: HiveAesCipher(
        keys,
      ),
    );
    return _collection;
  }

  @override
  Future<CollectionBox<V>> openBox<V>(
      {required String boxName,
      bool preload = false,
      CollectionBox<V> Function(String, BoxCollection)? boxCreator}) async {
    return await _collection.openBox<V>(
      boxName,
      preload: preload,
      boxCreator: boxCreator,
    );
  }

  @override
  Future<void> transaction(
    Future<void> Function() action, {
    List<String>? boxNames,
    bool readOnly = false,
  }) async {
    await _collection.transaction(action);
  }
}
